==> tds-4.6.5-sources.jar: thredds/server/config/FormatsAvailabilityService.java <==
/*
 * Copyright 1998-2014 University Corporation for Atmospheric Research/Unidata
 *
 *   Portions of this software were developed by the Unidata Program at the
 *   University Corporation for Atmospheric Research.
 *
 *   Access and use of this software shall impose the following obligations
 *   and understandings on the user. The user is granted the right, without
 *   any fee or cost, to use, copy, modify, alter, enhance and distribute
 *   this software, and any derivative works thereof, and its supporting
 *   documentation for any purpose whatsoever, provided that this entire
 *   notice appears in all copies of the software, derivative works and
 *   supporting documentation.  Further, UCAR requests that the user credit
 *   UCAR/Unidata in any publications that result from the use of this
 *   software or in any product that includes this software. The names UCAR
 *   and/or Unidata, however, may not be used in any advertising or publicity
 *   to endorse or promote any products or commercial entity unless specific
 *   written permission is obtained from UCAR/Unidata. The user also
 *   understands that UCAR/Unidata is not obligated to provide the user with
 *   any support, consulting, training or assistance of any kind with regard
 *   to the use, operation and performance of this software nor to provide
 *   the user with any updates, revisions, new versions or "bug fixes."
 *
 *   THIS SOFTWARE IS PROVIDED BY UCAR/UNIDATA "AS IS" AND ANY EXPRESS OR
 *   IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 *   WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 *   DISCLAIMED. IN NO EVENT SHALL UCAR/UNIDATA BE LIABLE FOR ANY SPECIAL,
 *   INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING
 *   FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
 *   NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION
 *   WITH THE ACCESS, USE OR PERFORMANCE OF THIS SOFTWARE.
 */

package thredds.server.config;

import org.springframework.stereotype.Service;
import thredds.server.ncss.format.SupportedFormat;

import java.util.HashMap;
import java.util.Map;

@Service
public final class FormatsAvailabilityService {

    private static Map<SupportedFormat, Boolean> formatsAvailability = new HashMap<>();

    static {
        //Default availabiliy
        formatsAvailability.put(SupportedFormat.XML_FILE, true);
        formatsAvailability.put(SupportedFormat.XML_STREAM, true);
        formatsAvailability.put(SupportedFormat.CSV_FILE, true);
        formatsAvailability.put(SupportedFormat.CSV_STREAM, true);
        formatsAvailability.put(SupportedFormat.NETCDF3, true);
        formatsAvailability.put(SupportedFormat.NETCDF4, false);
//        formatsAvailability.put(SupportedFormat.NETCDF4EXT, false);
        formatsAvailability.put(SupportedFormat.WKT, true);
        formatsAvailability.put(SupportedFormat.JSON, true);
        formatsAvailability.put(SupportedFormat.WATERML2, true);
    }

    private FormatsAvailabilityService() {

    }

    public static boolean isFormatAvailable(SupportedFormat format) {
        Boolean available = formatsAvailability.get(format);
        return (available == null) ? false : available;
    }

    static void setFormatAvailability(SupportedFormat format, boolean available) {

        formatsAvailability.put(format, available);
    }
}

==> tds-4.6.20-sources.jar: thredds/server/config/FormatsAvailabilityService.java <==
/*
 * Copyright 1998-2014 University Corporation for Atmospheric Research/Unidata
 *
 *   Portions of this software were developed by the Unidata Program at the
 *   University Corporation for Atmospheric Research.
 *
 *   Access and use of this software shall impose the following obligations
 *   and understandings on the user. The user is granted the right, without
 *   any fee or cost, to use, copy, modify, alter, enhance and distribute
 *   this software, and any derivative works thereof, and its supporting
 *   documentation for any purpose whatsoever, provided that this entire
 *   notice appears in all copies of the software, derivative works and
 *   supporting documentation.  Further, UCAR requests that the user credit
 *   UCAR/Unidata in any publications that result from the use of this
 *   software or in any product that includes this software. The names UCAR
 *   and/or Unidata, however, may not be used in any advertising or publicity
 *   to endorse or promote any products or commercial entity unless specific
 *   written permission is obtained from UCAR/Unidata. The user also
 *   understands that UCAR/Unidata is not obligated to provide the user with
 *   any support, consulting, training or assistance of any kind with regard
 *   to the use, operation and performance of this software nor to provide
 *   the user with any updates, revisions, new versions or "bug fixes."
 *
 *   THIS SOFTWARE IS PROVIDED BY UCAR/UNIDATA "AS IS" AND ANY EXPRESS OR
 *   IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 *   WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 *   DISCLAIMED. IN NO EVENT SHALL UCAR/UNIDATA BE LIABLE FOR ANY SPECIAL,
 *   INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING
 *   FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
 *   NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION
 *   WITH THE ACCESS, USE OR PERFORMANCE OF THIS SOFTWARE.
 */

package thredds.server.config;

import org.springframework.stereotype.Service;
import thredds.server.ncss.format.SupportedFormat;

import java.util.HashMap;
import java.util.Map;

@Service
public final class FormatsAvailabilityService {

    private static Map<SupportedFormat, Boolean> formatsAvailability = new HashMap<>();

    static {
        //Default availabiliy
        formatsAvailability.put(SupportedFormat.XML_FILE, true);
        formatsAvailability.put(SupportedFormat.XML_STREAM, true);
        formatsAvailability.put(SupportedFormat.CSV_FILE, true);
        formatsAvailability.put(SupportedFormat.CSV_STREAM, true);
        formatsAvailability.put(SupportedFormat.GEOCSV_FILE, true);
        formatsAvailability.put(SupportedFormat.GEOCSV_STREAM, true);
        formatsAvailability.put(SupportedFormat.NETCDF3, true);
        formatsAvailability.put(SupportedFormat.NETCDF4, false);
//        formatsAvailability.put(SupportedFormat.NETCDF4EXT, false);
        formatsAvailability.put(SupportedFormat.WKT, true);
        formatsAvailability.put(SupportedFormat.JSON, true);
        formatsAvailability.put(SupportedFormat.WATERML2, true);
    }

    private FormatsAvailabilityService() {

    }

    public static boolean isFormatAvailable(SupportedFormat format) {
        Boolean available = formatsAvailability.get(format);
        return (available == null) ? false : available;
    }

    static void setFormatAvailability(SupportedFormat format, boolean available) {

        formatsAvailability.put(format, available);
    }
}
